<?php
/* * ***********************************************************************
 * AcyMailing App for Watchful
 * Copyright (c) 2006-2013 Anything Digital & Inetis
 * ************************************************************************
 * Watchful.li is a web site monitoring and security service.
 * 
 * Although Watchful.li is a paid service, this program is free software;
 * you can redistribute it and/or modify it under the terms of the GNU 
 * General Public License as published by the Free Software Foundation; 
 * either version 2 of the License, or (at your option) any later version.
 *
 * This header must not be removed. Additional contributions/changes
 * may be added to this header as long as no information is deleted.
 * ************************************************************************
 * Get the latest version of this program at: https://watchful.li
 * *********************************************************************** */

// no direct access
defined('_JEXEC') or die();

require_once(JPATH_ADMINISTRATOR . '/components/com_watchfulli/classes/apps.php');
// We extend a base class to pass additional parameters in the language strings
// It will probably be included in the client but we also put it here so the app will work
// even for older version of the Watchful client.
class AcymailingAppAlert extends AppAlert
{
    public $parameter1;
    public $parameter2;
    public $parameter3;

    public function AcymailingAppAlert($level, $message, $parameter1 = null, $parameter2 = null, $parameter3 = null)
    {
        if ($level != null && $message != null)
        {
            $this->level = $level;
            $this->message = $message;
            $this->parameter1 = $parameter1;
            $this->parameter2 = $parameter2;
            $this->parameter3 = $parameter3;
        }
    }

}
class plgWatchfulliAppsAcymailingApp extends watchfulliApps
{

    public function createAppAlert($level, $message, $parameter1 = null, $parameter2 = null, $parameter3 = null)
    {
        $alert = new AcymailingAppAlert($level, $message, $parameter1, $parameter2, $parameter3);
        $this->addAlert($alert);
    }

    public function appMainProgram($oldValuesSerialized = null)
    {
        $this->setName("acymailingApp");
        $this->setDescription("Acymailing app to check if the queue is running.");
        $debug = $this->params->get('debug', 0);

        // Alert and return if AcyMailing not installed
        if (!file_exists(JPATH_ADMINISTRATOR . '/components/com_acymailing/helpers/helper.php'))
        {
            $this->createAppAlert(1, "ACYMAILINGAPP_NO_COMPONENT");
            return $this;
        }

        // Alert if there are blocked messages
        if (!$this->checkacy())
        {
            $this->createAppAlert(1, "ACYMAILINGAPP_QUEUE_BLOCKED");
        }
        return $this;
    }

    public function checkacy()
    {
        //we will compare all dates based on that one, two hours ago:
        $compareTime = time() - $this->params->get('delay', 1);
        if ($debug)
            $this->createAppAlert(1, "[DEBUG][ACYMAILINGAPP] Delay time: $compareTime");

        $db = & JFactory::getDBO();
        //We test if we have messages in the queue since more than the delay setting.
        $db->setQuery('SELECT senddate FROM #__acymailing_queue WHERE senddate < ' . $compareTime . ' LIMIT 1');
        $senddate = $db->loadResult();

        //Ok, no message in the queue waiting to be sent...
        if (empty($senddate))
            return true;

        //We found at least one message... Let's check the last message successfully sent by Acy
        $db->setQuery('SELECT MAX(senddate) FROM #__acymailing_userstats WHERE fail = 0');
        $lastmessagesent = $db->loadResult();

        //There is no message successfully sent or the last one has been sent more than 2 hours ago...
        //There is an issue and the queue is blocked!
        if ($lastmessagesent < $compareTime)
            return false;

        //Ok... we're all good, there are messages in the queue but they are sent regularly
        return true;
    }

}
